@@ -11,35 +11,45 @@ use App::TimelogTxt::Utils;
 use App::TimelogTxt::Day;
 use App::TimelogTxt::File;
 use App::TimelogTxt::Event;
+use Cwd ();
 
-our $VERSION = '0.03';
-
+our $VERSION = '0.04';
 
+# Initial configuration information.
 my %config = (
     editor => '',
     dir    => '',
     defcmd => '',
 );
-my $config_file = "$ENV{HOME}/.timelogrc";
 
+my $config_file =  _normalize_path( '~/.timelogrc' );
+
+# Dispatch table for commands
 my %commands = (
     'start' => {
         code     => \&start_event,
         clue     => 'start {event description}',
         abstract => 'Start timing a new event.',
-        help     => 'Stop last event and start timing a new event.',
+        help     => 'Stop the current event and start timing a new event.',
     },
     App::TimelogTxt::Utils::STOP_CMD() => {
         code => sub { my $app = shift; log_event( $app, App::TimelogTxt::Utils::STOP_CMD() ); },
         clue => App::TimelogTxt::Utils::STOP_CMD(),
-        abstract => 'Stop timing last event.',
-        help     => 'Stop timing last event.',
+        abstract => 'Stop timing the current event.',
+        help     => 'Stop timing the current event.',
+    },
+    'init' => {
+        code     => \&init_timelog,
+        clue     => 'init [directory]',
+        abstract => 'Create the timelog directory and configuration.',
+        help     => 'Create the directory and configuration file used by timelog
+if they do not already exist.',
     },
     'push' => {
         code     => \&push_event,
         clue     => 'push {event description}',
-        abstract => 'Save current event and start timing new.',
-        help     => 'Save last event on stack and start timing new event.',
+        abstract => 'Save the current event and start timing new.',
+        help     => 'Save the current event on stack and start timing new event.',
     },
     'pop' => {
         code     => \&pop_event,
@@ -51,7 +61,7 @@ my %commands = (
         code     => \&drop_event,
         clue     => 'drop [all|{n}]',
         abstract => 'Drop items from stack.',
-        help     => 'Drop one or more items from top of event stack, or all
+        help     => 'Drop one or more events from top of event stack, or all
 if argument supplied.',
     },
     'ls' => {
@@ -98,6 +108,8 @@ if argument supplied.',
     },
 );
 
+# Sub class of App::CmdDispatch that initializes configuration information
+# specific to this program. It also provides access to that configuration.
 {
     package Timelog::CmdDispatch;
     use base 'App::CmdDispatch';
@@ -117,17 +129,17 @@ if argument supplied.',
         my ($self) = @_;
         my $config = $self->get_config();
 
-        $config->{editor} ||= $config{editor} || $ENV{'VISUAL'} || $ENV{'EDITOR'} || '/usr/bin/vim';
-        $config->{dir}    ||= $config{dir} || "$ENV{HOME}/timelog";
+        $config->{editor} ||= $config{editor} || $ENV{'VISUAL'} || $ENV{'EDITOR'} || 'vim';
+        $config->{dir}    ||= $config{dir} || App::TimelogTxt::_normalize_path( '~/timelog' );
         $config->{defcmd} ||= $config{defcmd} || App::TimelogTxt::Utils::STOP_CMD();
-        $config->{'dir'} =~ s/~/$ENV{HOME}/;
+        $config->{dir} = App::TimelogTxt::_normalize_path( $config->{'dir'} );
         foreach my $d ( [qw/logfile timelog.txt/], [qw/stackfile stack.txt/] )
         {
             $config->{ $d->[0] } = "$config->{'dir'}/$d->[1]";
-            $config->{ $d->[0] } =~ s/~/$ENV{HOME}/;
         }
         return;
     }
+
 }
 
 sub run
@@ -139,7 +151,7 @@ sub run
     );
 
     my $options = {
-        config           => $config_file,
+        config           => (-f $config_file ? $config_file : undef),
         default_commands => 'help shell',
         'help:post_hint' =>
             "\nwhere [date] is an optional string specifying a date of the form YYYY-MM-DD
@@ -158,6 +170,31 @@ or a day name: yesterday, today, or sunday .. saturday.\n",
     return;
 }
 
+# Command handlers
+
+sub init_timelog
+{
+    my ($app, $dir) = @_;
+    require File::Path;
+    my $config = $app->get_config();
+    $dir //= $config->{'dir'};
+    $dir = _normalize_path( $dir );
+    File::Path::mkpath( $dir ) unless -d $dir;
+    unless( -f $config_file )
+    {
+        open my $fh, '>', $config_file;
+        # don't supply the editor value, default to the environment
+        print {$fh} <<"EOF";
+dir=$dir
+defcmd=$config->{defcmd}
+
+[alias]
+EOF
+    }
+    print "timelog initialized\n";
+    return;
+}
+
 sub log_event
 {
     my $app    = shift;
@@ -174,14 +211,6 @@ sub edit_logfile
     return;
 }
 
-sub _each_logline
-{
-    my ( $app, $code ) = @_;
-    open my $fh, '<', $app->_logfile;
-    $code->() while( <$fh> );
-    return;
-}
-
 sub list_events
 {
     my ( $app, $day ) = @_;
@@ -245,56 +274,6 @@ sub report_hours
     return;
 }
 
-sub extract_day_tasks
-{
-    my ( $app, $day, $eday ) = @_;
-
-    my $stamp = App::TimelogTxt::Utils::day_stamp( $day );
-    die "No day provided.\n" unless defined $stamp;
-    my $estamp = App::TimelogTxt::Utils::day_end( $eday ? App::TimelogTxt::Utils::day_stamp( $eday ) : $stamp );
-    my ( $summary, %last, @summaries );
-    my $event;
-    my $prev_stamp = '';
-
-    open my $fh, '<', $app->_logfile;
-    my $file = App::TimelogTxt::File->new( $fh, $stamp, $estamp );
-
-    while( defined( $_ = $file->readline ) )
-    {
-        eval {
-            $event = App::TimelogTxt::Event->new_from_line( $_ );
-        } or next;
-        if( $prev_stamp ne $event->stamp )
-        {
-            my $new_stamp = $event->stamp;
-            if( $summary and !$event->is_stop() )
-            {
-                $summary->update_dur( \%last, $new_stamp );
-                %last = ();
-            }
-            $summary = App::TimelogTxt::Day->new( $new_stamp );
-            push @summaries, $summary;
-            $prev_stamp = $new_stamp;
-        }
-        $summary->set_start( $event->epoch );
-        $summary->update_dur( \%last, $event->epoch );
-        $summary->start_task( $event );
-        %last = ($event->is_stop() ? () : $event->snapshot );
-    }
-
-    return [] unless $summary;
-
-    my $end_time = ( App::TimelogTxt::Utils::is_today( $day ) and !$event->is_stop() )
-        ? time
-        : App::TimelogTxt::Utils::stamp_to_localtime( $estamp );
-
-    $summary->update_dur( \%last, $end_time );
-
-    return if $summary->is_empty;
-
-    return \@summaries;
-}
-
 sub start_event
 {
     my ( $app, @event ) = @_;
@@ -302,13 +281,6 @@ sub start_event
     return;
 }
 
-sub _stack
-{
-    my ($app) = @_;
-    require App::TimelogTxt::Stack;
-    return App::TimelogTxt::Stack->new( $app->_stackfile );
-}
-
 sub push_event
 {
     my ( $app, @event ) = @_;
@@ -343,10 +315,107 @@ sub list_stack
     my ($app) = @_;
     return unless -f $app->_stackfile;
     my $stack = _stack( $app );
-    $stack->list();
+    $stack->list( \*STDOUT );
     return;
 }
 
+# Extract the daily events from the timelog.txt file and generate the list of Day
+# objects that encapsulates them.
+
+sub extract_day_tasks
+{
+    my ( $app, $day, $eday ) = @_;
+
+    my $stamp = App::TimelogTxt::Utils::day_stamp( $day );
+    die "No day provided.\n" unless defined $stamp;
+    my $estamp = App::TimelogTxt::Utils::day_end( $eday ? App::TimelogTxt::Utils::day_stamp( $eday ) : $stamp );
+    my ( $summary, $last, @summaries );
+    my $prev_stamp = '';
+
+    open my $fh, '<', $app->_logfile;
+    my $file = App::TimelogTxt::File->new( $fh, $stamp, $estamp );
+
+    use Data::Dumper;
+    while( defined( my $line = $file->readline ) )
+    {
+        my $event;
+        eval {
+            $event = App::TimelogTxt::Event->new_from_line( $line );
+        } or next;
+        if( $prev_stamp ne $event->stamp )
+        {
+            my $new_stamp = $event->stamp;
+            my $new_summary = App::TimelogTxt::Day->new( $new_stamp );
+            if( $summary and !$summary->is_complete() )
+            {
+                $summary->close_day( $last );
+                # Need to build a new last item beginning at midnight for the
+                # Previous event.
+                my $start = $summary->day_end()+1;
+                $last = App::TimelogTxt::Event->new( $last->task(), $start );
+                $new_summary->start_task( $last );
+            }
+            $summary = $new_summary;
+            push @summaries, $summary;
+            $prev_stamp = $new_stamp;
+        }
+        $summary->update_dur( $last, $event->epoch );
+        $summary->start_task( $event );
+        $last = ($event->is_stop() ? undef : $event );
+    }
+
+    return [] unless $summary;
+    my $end_time = ( App::TimelogTxt::Utils::is_today( $day ) and !($last and $last->is_stop()) )
+        ? time
+        : App::TimelogTxt::Utils::stamp_to_localtime( $estamp );
+
+    $summary->update_dur( $last, $end_time );
+
+    return if $summary->is_empty;
+
+    return \@summaries;
+}
+
+# Utility functions
+
+# Find user's home directory
+sub _home
+{
+    return $ENV{HOME} if defined $ENV{HOME};
+    if( $^O eq 'MSWin32' )
+    {
+        return "$ENV{HOMEDRIVE}$ENV{HOMEPATH}" if defined $ENV{HOMEPATH};
+        return $ENV{USERPROFILE} if defined $ENV{USERPROFILE};
+    }
+    return '/';
+}
+
+# Resolve ~ notation and convert to an absolute path.
+sub _normalize_path
+{
+    my ($path) = @_;
+
+    my $home = _home();
+    $path =~ s/~/$home/;
+
+    return Cwd::abs_path( $path );
+}
+
+sub _each_logline
+{
+    my ( $app, $code ) = @_;
+    open my $fh, '<', $app->_logfile;
+    $code->() while( <$fh> );
+    return;
+}
+
+sub _stack
+{
+    my ($app) = @_;
+    require App::TimelogTxt::Stack;
+    return App::TimelogTxt::Stack->new( $app->_stackfile );
+}
+
 sub _get_last_event
 {
     my ( $app ) = @_;
@@ -364,127 +433,203 @@ __END__
 
 App::TimelogTxt - Core code for timelog utility.
 
-
 =head1 VERSION
 
-This document describes App::TimelogTxt version 0.03
-
+This document describes App::TimelogTxt version 0.04
 
 =head1 SYNOPSIS
 
     use App::TimelogTxt;
+    App::TimelogTxt::run();
 
-=for author to fill in:
-    Brief code example(s) here showing commonest usage(s).
-    This section will be as far as many users bother reading
-    so make it as educational and exeplary as possible.
-  
-  
 =head1 DESCRIPTION
 
-=for author to fill in:
-    Write a full description of the module and its features here.
-    Use subsections (=head2, =head3) as appropriate.
+This module encapsulates all of the functionality of the timelog application.
+This module delegates much of the heavy lifting to other modules. It does
+handle the UI work and the configuration file.
 
+=head1 INTERFACE
 
-=head1 INTERFACE 
+At the moment, the only real interface to this file is the C<run> command.
 
-=for author to fill in:
-    Write a separate section listing the public components of the modules
-    interface. These normally consist of either subroutines that may be
-    exported, or methods that may be called on objects belonging to the
-    classes provided by the module.
+In the methods below, the C<$app> parameter is an object of the class
+C<Timelog::CmdDispatch>. This is a subclass of L<App::CmdDispatch> that adds
+support needed for some of our configuration.
 
+=head2 run()
 
-=head1 DIAGNOSTICS
+This is the main routine of the module. It creates the command parser object,
+parses the command line and dispatches the work to the correct function.
 
-=for author to fill in:
-    List every single error and warning message that the module can
-    generate (even the ones that will "never happen"), with a full
-    explanation of each problem, one or more likely causes, and any
-    suggested remedies.
+=head2 init_timelog( $app, $dir )
 
-=over
+Implementation of the 'init' command.
 
-=item C<< Error message here, perhaps with %s placeholders >>
+This routine creates the log directory if the directory doesn't exist. The
+optional C<$dir> argument is the path to this directory. If C<$dir> is not
+provided, use the default F<~/timelog> directory. If the configuration file
+doesn't exist, it creates that as well using the currently known values.
 
-[Description of error here]
+=head2 log_event( $app, @event );
 
-=item C<< Another error message here >>
+Add the specified event to the end of timelog.txt
 
-[Description of error here]
+=head2 edit_logfile( $app )
 
-[Et cetera, et cetera]
+Implementation of the 'edit' command.
 
-=back
+Open the F<timelog.txt> file in the configured editor.
 
+=head2 list_events( $app, $day )
+
+Implementation of the 'ls' command.
+
+Display the events for the supplied C<$day>. If no C<$day> is supplied, use
+today.
+
+=head2 list_projects( $app )
+
+Implementation of the 'lsproj' command.
+
+Extract all C<+project> entries from the events in F<timelog.txt> and display
+a sorted list, one per line.
+
+=head2 daily_report( $app, $day, $end_day )
+
+Implementation of the 'report' command.
+
+Display a report of all events for the given days on STDOUT. If C<$end_day> is
+not supplied, only display the report for C<$day>. If C<$day> is not supplied,
+default to today.
+
+=head2 daily_summary( $app, $day, $end_day )
+
+Implementation of the  'summary' command.
+
+Display a report of all project times for the given days on STDOUT. If
+C<$end_day> is not supplied, only display the report for C<$day>. If C<$day> is
+not supplied, default to today.
+
+=head2 report_hours( $app, $day, $end_day )
+
+Implementation of the 'hours' command.
+
+Display a report of the hours the given days on STDOUT. If C<$end_day> is not
+supplied, only display the report for C<$day>. If C<$day> is not supplied,
+default to today.
+
+=head2 extract_day_tasks( $app, $day, $end_day )
+
+Read the timelog.txt file and create an array of L<App::TimelogTxt::Day>
+objects that contain the information for the days from C<$day> to C<$end_day>.
+
+=head2 start_event( $app, @event )
+
+Implementation of the 'start' command.
+
+Add an event to the F<timelog.txt> file.
+
+=head2 push_event( $app, @event )
+
+Implementation of the 'push' command.
+
+Copy the current item from the timelog file to the stack and add the supplied
+event to the timelog file.
+
+=head2 pop_event( $app )
+
+Implementation of the 'pop' command.
+
+Remove the most recent event from the stack and add it as a new event to the
+timelog file.
+
+=head2 drop_event( $app, $arg )
+
+Implementation of the 'drop' command.
+
+Remove one or more items from the stack. If C<$arg> is not supplied, remove one
+item. If C<$arg> is a positive number, remove that many items from the stack.
+If C<$arg> is C<'all'>, clear the stack file.
+
+=head2 list_stack( $app )
+
+Implementation of the 'lstk' command.
+
+Print the current stack on STDOUT.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-=for author to fill in:
-    A full explanation of any configuration system(s) used by the
-    module, including the names and locations of any configuration
-    files, and the meaning of any environment variables or properties
-    that can be set. These descriptions must also include details of any
-    configuration language used.
-  
-App::TimelogTxt requires no configuration files or environment variables.
+App::TimelogTxt requires no environment variables, but may use VISUAL or
+EDITOR if an editor is not configured in F<~/.timelogrc>.
 
+App::TimelogTxt uses the file F<~/.timelogrc> for configuration information.
+
+The configuration file is expected to contain data in two major parts:
+
+=head2 General Configuration
+
+The first section defined general configuration information in a key=value
+format. The recognized keys are:
+
+=over 4
+
+=item editor
+
+The editor to use when opening the timelog file with the C<edit> command.
+If not specified, it will use the value of either the C<VISUAL> or C<EDITOR>
+environment variables. If non are found, it will default to C<vim>.
+
+=item dir
+
+The directory in which to find the timelog data files. Defaults to the
+C<timelog> directory in the user's home directory.
+
+=item defcmd
+
+The default command to by used if none is supplied to timelog. By default,
+this is the 'B<stop>' command.
+
+=back
+
+=head2 Command Aliases
+
+The config file may also contain an '[alias]' section that defines command
+aliases. Each alias is defined as a C<shortname=expanded string>
+
+For example, if you regularly need to make entries for reading email and
+triaging bug reports you might want the following in your configuration.
+
+  [alias]
+    email = start +Misc @Email
+    triage = start +BugTracker @Triage
 
 =head1 DEPENDENCIES
 
-=for author to fill in:
-    A list of all the other modules that this module relies upon,
-    including any restrictions on versions, and an indication whether
-    the module is part of the standard Perl distribution, part of the
-    module's distribution, or must be installed separately. ]
-
-None.
-
+App::CmdDispatch, Getopt::Long, File::Path, autodie.
 
 =head1 INCOMPATIBILITIES
 
-=for author to fill in:
-    A list of any modules that this module cannot be used in conjunction
-    with. This may be due to name conflicts in the interface, or
-    competition for system or program resources, or due to internal
-    limitations of Perl (for example, many modules that use source code
-    filters are mutually incompatible).
-
 None reported.
 
-
 =head1 BUGS AND LIMITATIONS
 
-=for author to fill in:
-    A list of known problems with the module, together with some
-    indication Whether they are likely to be fixed in an upcoming
-    release. Also a list of restrictions on the features the module
-    does provide: data types that cannot be handled, performance issues
-    and the circumstances in which they may arise, practical
-    limitations on the size of data sets, special cases that are not
-    (yet) handled, etc.
-
 No bugs have been reported.
 
 Please report any bugs or feature requests to
 C<bug-app-timelogtxt@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 G. Wade Johnson  C<< <gwadej@cpan.org> >>
 
-
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2013, G. Wade Johnson C<< <wade@cpan.org> >>. All rights reserved.
+Copyright (c) 2013, G. Wade Johnson C<< <gwadej@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
-
 =head1 DISCLAIMER OF WARRANTY
 
 BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
