@@ -4,8 +4,8 @@ use warnings;
 use strict;
 use Time::Local;
 use App::TimelogTxt::Utils;
- 
-our $VERSION = '0.03';
+
+our $VERSION = '0.04';
 
 sub new
 {
@@ -77,135 +77,100 @@ sub is_stop
     return ($_[0]->{task} eq App::TimelogTxt::Utils::STOP_CMD());
 }
 
-sub snapshot
-{
-    my ($self) = @_;
-    return %{$self};
-}
-
 1;
 __END__
 
 =head1 NAME
 
-ModName - [One line description of module's purpose here]
-
+App::TimelogTxt::Event - Class representing an event to log.
 
 =head1 VERSION
 
-This document describes ModName version 0.0.3
-
+This document describes ModName version 0.04
 
 =head1 SYNOPSIS
 
-    use ModName;
+    use App::TimelogTxt::Event;
+
+    my @events;
+    while(<>)
+    {
+        my $event = App::TimelogTxt::Event->new_from_line( $_ );
+        if( $event->stamp eq $wanted_stamp )
+        {
+            push @events, $event;
+        }
+    }
 
-=for author to fill in:
-    Brief code example(s) here showing commonest usage(s).
-    This section will be as far as many users bother reading
-    so make it as educational and exeplary as possible.
-  
-  
 =head1 DESCRIPTION
 
-=for author to fill in:
-    Write a full description of the module and its features here.
-    Use subsections (=head2, =head3) as appropriate.
+Objects of this class represent the individual lines in the F<timelog.txt> file.
+Each event has a date and time stamp, an optional project, and a task.
 
+=head1 INTERFACE
 
-=head1 INTERFACE 
+=head2 new( $task, $time )
 
-=for author to fill in:
-    Write a separate section listing the public components of the modules
-    interface. These normally consist of either subroutines that may be
-    exported, or methods that may be called on objects belonging to the
-    classes provided by the module.
+Create a new object representing the supplied C<$task> at the supplied epoch
+C<$time>. If no C<$time> is supplied, use the current time.
 
+=head2 new_from_line( $line )
 
-=head1 DIAGNOSTICS
+Create a new object representing the event from the supplied line. This event
+must be formatted as described in L<App::TimelogTxt::Format>.
 
-=for author to fill in:
-    List every single error and warning message that the module can
-    generate (even the ones that will "never happen"), with a full
-    explanation of each problem, one or more likely causes, and any
-    suggested remedies.
+=head2 $event->task()
 
-=over
+Return a string containing all of the event except the time and date.
 
-=item C<< Error message here, perhaps with %s placeholders >>
+=head2 $event->project()
 
-[Description of error here]
+Return the string designated as the project, if any, from the event.
 
-=item C<< Another error message here >>
+=head2 $event->to_string()
 
-[Description of error here]
+Return a string representing the event, formatted as described in
+L<App::TimelogTxt::Format>.
 
-[Et cetera, et cetera]
+=head2 $event->epoch()
 
-=back
+Return the time for the start of the event in epoch seconds.
 
+=head2 $event->stamp()
+
+Return the date stamp of the event in 'YYYY-MM-DD' format.
+
+=head2 $event->is_stop()
+
+Return C<true> if this was a stop event.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-=for author to fill in:
-    A full explanation of any configuration system(s) used by the
-    module, including the names and locations of any configuration
-    files, and the meaning of any environment variables or properties
-    that can be set. These descriptions must also include details of any
-    configuration language used.
-  
-ModName requires no configuration files or environment variables.
-
+App::TimelogTxt::Event requires no configuration files or environment variables.
 
 =head1 DEPENDENCIES
 
-=for author to fill in:
-    A list of all the other modules that this module relies upon,
-    including any restrictions on versions, and an indication whether
-    the module is part of the standard Perl distribution, part of the
-    module's distribution, or must be installed separately. ]
-
-None.
-
+Time:Local.
 
 =head1 INCOMPATIBILITIES
 
-=for author to fill in:
-    A list of any modules that this module cannot be used in conjunction
-    with. This may be due to name conflicts in the interface, or
-    competition for system or program resources, or due to internal
-    limitations of Perl (for example, many modules that use source code
-    filters are mutually incompatible).
-
 None reported.
 
-
 =head1 BUGS AND LIMITATIONS
 
-=for author to fill in:
-    A list of known problems with the module, together with some
-    indication Whether they are likely to be fixed in an upcoming
-    release. Also a list of restrictions on the features the module
-    does provide: data types that cannot be handled, performance issues
-    and the circumstances in which they may arise, practical
-    limitations on the size of data sets, special cases that are not
-    (yet) handled, etc.
-
 No bugs have been reported.
 
 =head1 AUTHOR
 
-G. Wade Johnson  C<< wade@anomaly.org >>
-
+G. Wade Johnson  C<< gwadej@cpan.org >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) <YEAR>, G. Wade Johnson C<< wade@anomaly.org >>. All rights reserved.
+Copyright (c) 2013, G. Wade Johnson C<< gwadej@cpan.org >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
-
 =head1 DISCLAIMER OF WARRANTY
 
 BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
@@ -228,4 +193,3 @@ RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
 FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
 SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGES.
-
