@@ -3,7 +3,7 @@ package App::TimelogTxt::File;
 use warnings;
 use strict;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub new {
     my ($class, $fh, $start, $end) = @_;
@@ -56,10 +56,9 @@ __END__
 
 App::TimelogTxt::File - Simplify reading part of the timelog.txt file
 
-
 =head1 VERSION
 
-This document describes App::TimelogTxt::File version 0.03
+This document describes App::TimelogTxt::File version 0.04
 
 =head1 SYNOPSIS
 
@@ -81,30 +80,19 @@ the readline function.
 
 =head2 new( $file, $start, $end )
 
-=head2 readline()
+Create an object representing part of a file. The C<$file> argument gives the
+file path. The C<$start> and C<$end> parameters specify the markers for the 
+starting and ending parts of the file.
 
-=head1 DIAGNOSTICS
-
-=over
-
-=item C<< Error message here, perhaps with %s placeholders >>
-
-[Description of error here]
-
-=item C<< Another error message here >>
-
-[Description of error here]
-
-[Et cetera, et cetera]
-
-=back
+=head2 $f->readline()
 
+Return the next line from the file that meets the criteria. Returns C<undef>
+once we reach either the end of file or the C<$end> marker.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
 App::TimelogTxt::File requires no configuration files or environment variables.
 
-
 =head1 DEPENDENCIES
 
 None.
@@ -113,24 +101,21 @@ None.
 
 None reported.
 
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 =head1 AUTHOR
 
-G. Wade Johnson  C<< wade@anomaly.org >>
-
+G. Wade Johnson  C<< gwadej@cpan.org >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2012, G. Wade Johnson C<< wade@anomaly.org >>. All rights reserved.
+Copyright (c) 2012, G. Wade Johnson C<< gwadej@cpan.org >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
-
 =head1 DISCLAIMER OF WARRANTY
 
 BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
@@ -153,4 +138,3 @@ RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
 FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
 SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGES.
-
