@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use autodie;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub new
 {
@@ -41,6 +41,7 @@ sub _pop
     open my $fh, '+<', $self->{file};
     my ($line, $pos) = _find_last_line( $fh );
     return unless defined $line;
+
     seek( $fh, $pos, 0 );
     truncate( $fh, $pos );
     return $line;
@@ -74,6 +75,7 @@ sub _find_last_line
         ( $lastpos, $lastline ) = ( $pos, $line );
     }
     return unless defined $lastline;
+
     chomp $lastline;
     return ($lastline, $lastpos);
 }
@@ -89,36 +91,36 @@ sub _readline_pos
 
 sub list
 {
-    my ($self) = @_;
+    my ($self, $ofh) = @_;
+    $ofh ||= \*STDOUT;
     return unless -f $self->{file};
+
     open my $fh, '<', $self->{file};
-    print reverse <$fh>;
+    print {$ofh} reverse <$fh>;
     return;
 }
 
 1;
+
 __END__
 
 =head1 NAME
 
-ModName - [One line description of module's purpose here]
-
+App::TimelogTxt::Stack - Interface to the stack file for the timelog application.
 
 =head1 VERSION
 
-This document describes ModName version 0.03
-
+This document describes App::TimelogTxt::Stack version 0.04
 
 =head1 SYNOPSIS
 
-    use ModName;
+    use App::TimelogTxt::Stack;
+
+    my $stack = App::TimelogTxt::Stack->new( 'timelog/stack.txt' );
+
+    $stack->push( '+Project @Task More detail' );
+    my $event = $stack->pop();
 
-=for author to fill in:
-    Brief code example(s) here showing commonest usage(s).
-    This section will be as far as many users bother reading
-    so make it as educational and exeplary as possible.
-  
-  
 =head1 DESCRIPTION
 
 =for author to fill in:
@@ -126,99 +128,63 @@ This document describes ModName version 0.03
     Use subsections (=head2, =head3) as appropriate.
 
 
-=head1 INTERFACE 
+=head1 INTERFACE
 
-=for author to fill in:
-    Write a separate section listing the public components of the modules
-    interface. These normally consist of either subroutines that may be
-    exported, or methods that may be called on objects belonging to the
-    classes provided by the module.
+=head2 new( $filename )
 
+Create an C<App::TimelogTxt::Stack> object wrapping the supplied file.
 
-=head1 DIAGNOSTICS
+=head2 $s->clear()
 
-=for author to fill in:
-    List every single error and warning message that the module can
-    generate (even the ones that will "never happen"), with a full
-    explanation of each problem, one or more likely causes, and any
-    suggested remedies.
+Truncate the stack file, removing all items from the stack.
 
-=over
+=head2 $s->push( $event )
 
-=item C<< Error message here, perhaps with %s placeholders >>
+Add a new event to the stack file.
 
-[Description of error here]
+=head2 $event = $s->pop()
 
-=item C<< Another error message here >>
+Remove the most recent event from the stack file and return the event string.
 
-[Description of error here]
+=head2 $s->drop( $arg )
 
-[Et cetera, et cetera]
+Remove one or more events from the stack file. If C<$arg> is not supplied,
+remove one item. If C<$arg> is a positive number, remove that many items
+from the stack. If C<$arg> is the string C<'all'>, clear the stack.
 
-=back
+=head2 $s->list( $fh )
 
+Print the stack to the supplied filehandle. If no filehandle is supplied, use
+C<STDOUT>. The stack will be printed such that the most recent item is listed
+first.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-=for author to fill in:
-    A full explanation of any configuration system(s) used by the
-    module, including the names and locations of any configuration
-    files, and the meaning of any environment variables or properties
-    that can be set. These descriptions must also include details of any
-    configuration language used.
-  
-ModName requires no configuration files or environment variables.
-
+App::TimelogTxt::Stack requires no configuration files or environment variables.
 
 =head1 DEPENDENCIES
 
-=for author to fill in:
-    A list of all the other modules that this module relies upon,
-    including any restrictions on versions, and an indication whether
-    the module is part of the standard Perl distribution, part of the
-    module's distribution, or must be installed separately. ]
-
-None.
-
+autodie.
 
 =head1 INCOMPATIBILITIES
 
-=for author to fill in:
-    A list of any modules that this module cannot be used in conjunction
-    with. This may be due to name conflicts in the interface, or
-    competition for system or program resources, or due to internal
-    limitations of Perl (for example, many modules that use source code
-    filters are mutually incompatible).
-
 None reported.
 
-
 =head1 BUGS AND LIMITATIONS
 
-=for author to fill in:
-    A list of known problems with the module, together with some
-    indication Whether they are likely to be fixed in an upcoming
-    release. Also a list of restrictions on the features the module
-    does provide: data types that cannot be handled, performance issues
-    and the circumstances in which they may arise, practical
-    limitations on the size of data sets, special cases that are not
-    (yet) handled, etc.
-
 No bugs have been reported.
 
 =head1 AUTHOR
 
-G. Wade Johnson  C<< wade@anomaly.org >>
-
+G. Wade Johnson  C<< gwadej@cpan.org >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) <YEAR>, G. Wade Johnson C<< wade@anomaly.org >>. All rights reserved.
+Copyright (c) 2013, G. Wade Johnson C<< gwadej@cpan.org >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
-
 =head1 DISCLAIMER OF WARRANTY
 
 BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
